@@ -11,7 +11,7 @@ class Session:
         self.base_url = base_url
 
     def request(
-        self, method: str, path: str, params: dict = None, data: dict = None
+            self, method: str, path: str, params: dict = None, data: dict = None
     ) -> dict:
 
         if data:
@@ -26,6 +26,6 @@ class Session:
                 method, f"{self.base_url}{path}", params=params, headers=self.headers
             )
 
-        if res.status_code > 299 or res.json().get("error"):
+        if res and res.status_code > 299:
             raise APIException(res.json())
         return res.json()
